#!/bin/bash
: '
/*
 * Legal Notice
 *
 * This document and associated source code (the "Work") is a part of a
 * benchmark specification maintained by the TPC.
 *
 * The TPC reserves all right, title, and interest to the Work as provided
 * under U.S. and international laws, including without limitation all patent
 * and trademark rights therein.
 *
 * No Warranty
 *
 * 1.1 TO THE MAXIMUM EXTENT PERMITTED BY APPLICABLE LAW, THE INFORMATION
 *     CONTAINED HEREIN IS PROVIDED "AS IS" AND WITH ALL FAULTS, AND THE
 *     AUTHORS AND DEVELOPERS OF THE WORK HEREBY DISCLAIM ALL OTHER
 *     WARRANTIES AND CONDITIONS, EITHER EXPRESS, IMPLIED OR STATUTORY,
 *     INCLUDING, BUT NOT LIMITED TO, ANY (IF ANY) IMPLIED WARRANTIES,
 *     DUTIES OR CONDITIONS OF MERCHANTABILITY, OF FITNESS FOR A PARTICULAR
 *     PURPOSE, OF ACCURACY OR COMPLETENESS OF RESPONSES, OF RESULTS, OF
 *     WORKMANLIKE EFFORT, OF LACK OF VIRUSES, AND OF LACK OF NEGLIGENCE.
 *     ALSO, THERE IS NO WARRANTY OR CONDITION OF TITLE, QUIET ENJOYMENT,
 *     QUIET POSSESSION, CORRESPONDENCE TO DESCRIPTION OR NON-INFRINGEMENT
 *     WITH REGARD TO THE WORK.
 * 1.2 IN NO EVENT WILL ANY AUTHOR OR DEVELOPER OF THE WORK BE LIABLE TO
 *     ANY OTHER PARTY FOR ANY DAMAGES, INCLUDING BUT NOT LIMITED TO THE
 *     COST OF PROCURING SUBSTITUTE GOODS OR SERVICES, LOST PROFITS, LOSS
 *     OF USE, LOSS OF DATA, OR ANY INCIDENTAL, CONSEQUENTIAL, DIRECT,
 *     INDIRECT, OR SPECIAL DAMAGES WHETHER UNDER CONTRACT, TORT, WARRANTY,
 *     OR OTHERWISE, ARISING IN ANY WAY OUT OF THIS OR ANY OTHER AGREEMENT
 *     RELATING TO THE WORK, WHETHER OR NOT SUCH AUTHOR OR DEVELOPER HAD
 *     ADVANCE NOTICE OF THE POSSIBILITY OF SUCH DAMAGES.
 */
'

LU_COUNT=0
FLAT_OUT=""

TEMP=`getopt -o l:f: --long lu_count:,flat_out: -n $0 -- "$@"`
if [ $? != 0 ] ; then
    echo -e "Usage:\t$0 <parameters>" >&2
    echo -e "\t-f <dir>|--flat_out <dir>\tCreate the flat files in subdirectories under <dir>" >&2
    echo -e "\t-l <size>|--lu_count <size>\tTotal Load Units divided over 4 partitions" >&2
    exit 1
fi

eval set -- "$TEMP"

while true ; do
    case $1 in
	-l|--lu_count) LU_COUNT=$2; shift 2 ;;
	-f|--flat_out) FLAT_OUT=$2; shift 2 ;;
	--) shift ; break ;;
	*) echo "Internal error!" ; exit 1 ;;
    esac
done
if test $LU_COUNT -eq 0 -o "X${FLAT_OUT}" = "X" ; then
    echo "$0: need both the -f|--flat_out <dir> and -l|--lu_count <size> parameters to be specified"
    echo -e "Usage:\t$0 <parameters>" >&2
    echo -e "\t-f <dir>|--flat_out <dir>\tCreate the flat files in subdirectories under <dir>" >&2
    echo -e "\t-l <size>|--lu_count <size>\tTotal Load Units divided over 4 partitions" >&2
    exit 1
fi

QUARTER_LUS=`expr $LU_COUNT / 4`
REM=`expr $LU_COUNT - \( $QUARTER_LUS \* 4 \)`
if test $REM -ne 0; then
    echo "$0: LU count of $LU_COUNT is not a multiple of 4"
    exit 1
fi
CUST_COUNT=`expr $LU_COUNT \* 1000`
QUARTER=`expr $CUST_COUNT / 4`

cd /opt/VGen
mkdir -p ${FLAT_OUT}/Fixed
mkdir -p ${FLAT_OUT}/Scaling1
mkdir -p ${FLAT_OUT}/Scaling2
mkdir -p ${FLAT_OUT}/Scaling3
mkdir -p ${FLAT_OUT}/Scaling4
bin/VGenLoader -xf -c $CUST_COUNT -t $CUST_COUNT -w 125 -o ${FLAT_OUT}/Fixed &
bin/VGenLoader -xd -b 1 -c $QUARTER -t $CUST_COUNT -w 125 -o ${FLAT_OUT}/Scaling1 &
BEGIN=`expr $QUARTER + 1`
bin/VGenLoader -xd -b $BEGIN -c $QUARTER -t $CUST_COUNT -w 125 -o ${FLAT_OUT}/Scaling2 &
BEGIN=`expr $BEGIN + $QUARTER`
bin/VGenLoader -xd -b $BEGIN -c $QUARTER -t $CUST_COUNT -w 125 -o ${FLAT_OUT}/Scaling3 &
BEGIN=`expr $BEGIN + $QUARTER`
bin/VGenLoader -xd -b $BEGIN -c $QUARTER -t $CUST_COUNT -w 125 -o ${FLAT_OUT}/Scaling4 &
wait 
